==> kubernetes-model-1.0.31-sources.jar: io/fabric8/kubernetes/api/model/RootPathsFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class RootPathsFluentImpl<T extends RootPathsFluent<T>> extends BaseFluent<T> implements RootPathsFluent<T>{

     List<String> paths = new ArrayList();     Map<String, Object> additionalProperties = new HashMap();

    public T addToPaths( String ...items){
    for (String item : items) {this.paths.add(item);} return (T)this;
    }
    public T removeFromPaths( String ...items){
    for (String item : items) {this.paths.remove(item);} return (T)this;
    }
    public List<String> getPaths(){
    return this.paths;
    }
    public T withPaths( List<String> paths){
    this.paths.clear();if (paths != null) {for (String item : paths){this.addToPaths(item);}} return (T) this;
    }
    public T withPaths( String ...paths){
    this.paths.clear(); if (paths != null) {for (String item :paths){ this.addToPaths(item);}} return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
RootPathsFluentImpl that = (RootPathsFluentImpl) o;
if (paths != null ? !paths.equals(that.paths) :that.paths != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.49-sources.jar: io/fabric8/kubernetes/api/model/RootPathsFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.ArrayList;
import java.util.RandomAccess;
import java.util.Map;
import java.util.Map;
import java.util.List;
import java.util.List;
import java.util.AbstractCollection;
import java.util.AbstractList;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Collection;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class RootPathsFluentImpl<T extends RootPathsFluent<T>> extends BaseFluent<T> implements RootPathsFluent<T>{

     List<String> paths = new ArrayList();     Map<String, Object> additionalProperties = new HashMap();
public RootPathsFluentImpl(){
    
}
public RootPathsFluentImpl( RootPaths instance ){
    this.withPaths(instance.getPaths()); 
}

    public T addToPaths( String ...items){
    for (String item : items) {this.paths.add(item);} return (T)this;
    }
    public T removeFromPaths( String ...items){
    for (String item : items) {this.paths.remove(item);} return (T)this;
    }
    public List<String> getPaths(){
    return this.paths;
    }
    public T withPaths( List<String> paths){
    this.paths.clear();if (paths != null) {for (String item : paths){this.addToPaths(item);}} return (T) this;
    }
    public T withPaths( String ...paths){
    this.paths.clear(); if (paths != null) {for (String item :paths){ this.addToPaths(item);}} return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
RootPathsFluentImpl that = (RootPathsFluentImpl) o;
if (paths != null ? !paths.equals(that.paths) :that.paths != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
